<?php
/**
 * Xponent Standard child theme.
 *
 * This file adds the Customizer additions to the Xponent Standard child theme.
 *
 * @package Xponent Standard
 * @author  Xponent
 * @license GPL-2.0-or-later
 * @link    https://xponent.se/themes/
 */

add_action( 'customize_register', 'xponent_standard_customizer_register' );
/**
 * Registers settings and controls with the Customizer.
 *
 * @since 2.2.3
 *
 * @param WP_Customize_Manager $wp_customize Customizer object.
 */
function xponent_standard_customizer_register( $wp_customize ) {

	$wp_customize->add_setting(
		'xponent_standard_link_color',
		array(
			'default'           => xponent_standard_customizer_get_default_link_color(),
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'xponent_standard_link_color',
			array(
				'description' => __( 'Change the color of post info links, hover color of linked titles, hover color of menu items, and more.', 'xponent-standard' ),
				'label'       => __( 'Link Color', 'xponent-standard' ),
				'section'     => 'colors',
				'settings'    => 'xponent_standard_link_color',
			)
		)
	);

	$wp_customize->add_setting(
		'xponent_standard_accent_color',
		array(
			'default'           => xponent_standard_customizer_get_default_accent_color(),
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'xponent_standard_accent_color',
			array(
				'description' => __( 'Change the default hover color for button links, the menu button, and submit buttons. This setting does not apply to buttons created with the Buttons block.', 'xponent-standard' ),
				'label'       => __( 'Accent Color', 'xponent-standard' ),
				'section'     => 'colors',
				'settings'    => 'xponent_standard_accent_color',
			)
		)
	);

	$wp_customize->add_setting(
		'xponent_standard_logo_width',
		array(
			'default'           => 350,
			'sanitize_callback' => 'absint',
		)
	);

	// Add a control for the logo size.
	$wp_customize->add_control(
		'xponent_standard_logo_width',
		array(
			'label'       => __( 'Logo Width', 'xponent-standard' ),
			'description' => __( 'The maximum width of the logo in pixels.', 'xponent-standard' ),
			'priority'    => 9,
			'section'     => 'title_tagline',
			'settings'    => 'xponent_standard_logo_width',
			'type'        => 'number',
			'input_attrs' => array(
				'min' => 100,
			),

		)
	);

}
